from Init import *

##--------------------------------------------------------------------------
## Module that calculates surface weather elements from cras45 model output.
##--------------------------------------------------------------------------
class cras45Forecaster(Forecaster):
    def __init__(self):
        Forecaster.__init__(self, "cras45", "cras45")

    def levels(self):
        return ["MB1000", "MB950", "MB925", "MB900", "MB850", "MB800",
                "MB750", "MB700", "MB650", "MB600", "MB550", "MB500",
                "MB450", "MB400", "MB350", "MB300", "MB250", "MB200",
                "MB150", "MB100"]

    def calcMaxT(self, T, MaxT):
        if MaxT is None:
            return T
        return maximum(MaxT, T)

    def calcMinT(self, T, MinT):
        if MinT is None:
            return T
        return minimum(MinT, T)

    def calcT(self, t_FHAG2):
        t = t_FHAG2
        return self.KtoF(t)

    def calcTd(self, dpt_FHAG2):
        td = dpt_FHAG2
        return self.KtoF(td)

    def calcRH(self, T, Td):
        Tc = .556 * (T - 32.0)
        Tdc = .556 * (Td - 32.0)
        Vt = 6.11 * pow(10, (Tc * 7.5 / (Tc + 237.3)))
        Vd = 6.11 * pow(10, (Tdc * 7.5 / (Tdc + 237.3)))
        RH = (Vd / Vt) * 100.0
        return RH

    def calcMaxRH(self, RH, MaxRH):
        if MaxRH is None:
            return RH
        return maximum(MaxRH, RH)

    def calcMinRH(self, RH, MinRH):
        if MinRH is None:
            return RH
        return minimum(MinRH, RH)

    def calcQPF(self, tp_SFC):
        qpf = tp_SFC / 25.4   # convert from millimeters to inches
        return qpf

    def calcSky(self, tcc_EA):
        sky = clip(tcc_EA, 0, 100)
        return sky

    def calcWind(self, wind_FHAG10):
        mag = wind_FHAG10[0]  # get the wind grids
        dir = wind_FHAG10[1]  # get wind dir
        mag = mag * 1.94      # convert to knots
        dir = clip(dir, 0, 359.5)
        return (mag, dir)      # assemble speed and dir into a tuple

def main():
    cras45Forecaster().run()

if __name__ == "__main__":
    main()
